@@ -1,10 +1,8 @@
 mutossGUI.vars <- list()
 
 startRecording <- function() {
-	mutossGUI.vars$output <<- "output" # TODO These variablenames are stupid! But there was some bug with hidden ones or non-global ones?
-	mutossGUI.vars$errorMsg <<- "errorMsg"
-	mutossGUI.vars$outputCon <<- textConnection(mutossGUI.vars$output, open="w")
-	mutossGUI.vars$errorCon <<- textConnection(mutossGUI.vars$errorMsg, open="w")
+	mutossGUI.vars$outputCon <- textConnection(".mutossGUIoutput", open="w")
+	mutossGUI.vars$errorCon <- textConnection(".mutossGUIerrorMsg", open="w")
 	sink(mutossGUI.vars$outputCon)
 	sink(mutossGUI.vars$errorCon, type="message")
 }
@@ -12,8 +10,8 @@ startRecording <- function() {
 stopRecording <- function() {
 	sink()
 	sink(type="message")
-	close(mutossGUI.vars$outputCon)
-	close(mutossGUI.vars$errorCon)
+	try(close(mutossGUI.vars$outputCon), silent = TRUE)
+	try(close(mutossGUI.vars$errorCon), silent = TRUE)
 	return(list(output=mutossGUI.vars$output, errorMsg=mutossGUI.vars$errorMsg))
 }
 
@@ -21,4 +19,18 @@ myContrMat <- function(type,l,df,group) {
 	require(multcomp)
 	n <- table(df[,group])[as.numeric(factor(l,levels=levels(df[,group])))]
 	x <- contrMat(n=n,type=type)
-}
\ No newline at end of file
+}
+
+myContrMat <- function(type,l,df,group) {
+	require(multcomp)
+	n <- table(df[,group])[as.numeric(factor(l,levels=levels(df[,group])))]
+	x <- contrMat(n=n,type=type)
+}
+
+getOutput <- function() {
+	return(.mutossGUIoutput)
+}
+
+getErrorMsg <- function() {
+	return(.mutossGUIerrorMsg)
+}
